@@ -189,6 +189,8 @@ class AbstractTransactionPending:
         :param customer_email_address: The customer_email_address of this AbstractTransactionPending.
         :type: str
         """
+        if customer_email_address is not None and len(customer_email_address) > 254:
+            raise ValueError("Invalid value for `customer_email_address`, length must be less than or equal to `254`")
 
         self._customer_email_address = customer_email_address
     
@@ -258,6 +260,8 @@ class AbstractTransactionPending:
         :param invoice_merchant_reference: The invoice_merchant_reference of this AbstractTransactionPending.
         :type: str
         """
+        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
+            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")
 
         self._invoice_merchant_reference = invoice_merchant_reference
     
@@ -327,6 +331,8 @@ class AbstractTransactionPending:
         :param merchant_reference: The merchant_reference of this AbstractTransactionPending.
         :type: str
         """
+        if merchant_reference is not None and len(merchant_reference) > 100:
+            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")
 
         self._merchant_reference = merchant_reference
     
@@ -396,6 +402,8 @@ class AbstractTransactionPending:
         :param shipping_method: The shipping_method of this AbstractTransactionPending.
         :type: str
         """
+        if shipping_method is not None and len(shipping_method) > 200:
+            raise ValueError("Invalid value for `shipping_method`, length must be less than or equal to `200`")
 
         self._shipping_method = shipping_method
     
